@@ -51,10 +51,10 @@ SampleOne <- function(x, len = length(x)) {
 #'
 #' @export
 UnshiftTree <- function(add, treeList) {
-  if (inherits(treeList, 'multiPhylo')) {
-    structure(c(list(add), lapply(treeList, I)), class = 'multiPhylo')
-  } else if (inherits(treeList, 'phylo')) {
-    structure(list(add, treeList), class = 'multiPhylo')
+  if (inherits(treeList, "multiPhylo")) {
+    structure(c(list(add), lapply(treeList, I)), class = "multiPhylo")
+  } else if (inherits(treeList, "phylo")) {
+    structure(list(add, treeList), class = "multiPhylo")
   } else { # including: if (is.list(trees)) {
     c(list(add), treeList)
   }
@@ -80,14 +80,14 @@ UnshiftTree <- function(add, treeList) {
 #' @seealso [`bit64::integer64()`][bit64-package]
 #' @export
 sapply64 <- function(X, FUN, ..., simplify = TRUE, USE.NAMES = TRUE) {
-  structure(sapply(X, FUN, ..., simplify, USE.NAMES), class = 'integer64')
+  structure(sapply(X, FUN, ..., simplify, USE.NAMES), class = "integer64")
 }
 
 #' @rdname sapply64
 #' @export
 vapply64 <- function(X, FUN, FUN.LEN = 1, ...) {
   structure(vapply(X, FUN, FUN.VALUE = numeric(FUN.LEN), ...),
-            class = 'integer64')
+            class = "integer64")
 }
 
 #' @rdname sapply64
@@ -113,24 +113,39 @@ replicate64 <- function(n, expr, simplify = "array") {
 #' @param palette Colour palette to depict.
 #' @param lwd,lty,lend Additional parameters to [`segments()`],
 #' controlling line style.
+#' @param cex Character expansion factor relative to current `par("cex")`.
+#' @param text.col Colour used for the legend text.
+#' @param font,text.font Font used for the legend text; see [`text()`].
+#' @param title Text to display 
+#' @param title.col Colour for title; defaults to `text.col[1]`.
+#' @param title.cex Expansion factor(s) for the title, defaults to `cex[1]`.
+#' @param title.adj Horizontal adjustment for title: see the help for
+#' `par("adj")`.
+#' @param title.font Font used for the legend title.
 #' @param pos,\dots Additional parameters to [`text()`].
 #' 
 #' @examples 
 #' plot(0:1, 0:1, type = "n", frame.plot = FALSE,
 #'      xlab = "x", ylab = "y")
 #' SpectrumLegend(legend = c("Dark", "Middle", "Bright"),
-#'                palette = hcl.colors(32L), lwd = 5)
+#'                palette = hcl.colors(32L), lwd = 5,
+#'                title = "Brightness")
 #' SpectrumLegend(0.4, 0.95, 0.9, 0.95, abs = TRUE,
-#'                legend = seq(1, 9, by = 2), palette = 1:9, pos = 1)
+#'                legend = seq(1, 9, by = 2), palette = 1:8, pos = 1)
 #' @template MRS
-#' @importFrom graphics segments text
+#' @importFrom graphics segments strheight strwidth text
 #' @export
 SpectrumLegend <- function(x0 = 0.05, y0 = 0.05,
                            x1 = x0, y1 = y0 + 0.2,
                            absolute = FALSE,
                            legend = character(0), palette,
-                           lwd = 4, lty = 1, lend = "square",
-                           pos = 4, ...) {
+                           lwd = 4, lty = 1, lend = "square", cex = 1,
+                           text.col = par("col"),
+                           font = NULL, text.font = font,
+                           title = NULL, title.col = text.col[1], 
+                           title.cex = cex[1], title.adj = 0.5, title.font = 2,
+                           pos = 4,
+                           ...) {
   nCol <- length(palette)
   
   if (!absolute) {
@@ -155,6 +170,18 @@ SpectrumLegend <- function(x0 = 0.05, y0 = 0.05,
            lwd = lwd, lty = lty, lend = lend)
   text(seq(x0, x1, length.out = length(legend)),
        seq(y0, y1, length.out = length(legend)),
+       col = text.col,
+       font = text.font,
        legend, pos = pos, ...)
+  if (!is.null(title)) {
+    text(mean(x0, x1) + (max(strwidth(legend)) / ifelse(pos == 2, -2, 2)),
+         max(y0, y1) + prod(
+           par("lheight"),
+           strheight("")
+         ),
+         title,
+         pos = 3,
+         cex = title.cex, adj = title.adj, font = title.font, col = title.col,
+         ...)
+  }
 }
-
