@@ -4,7 +4,7 @@ nasty <- structure(list(edge = structure(
   .Dim = c(12, 2)),
   Nnode = 5L,
   tip.label = letters[1:8]),
-  class = 'phylo') # Danger: Do not plot!
+  class = "phylo") # Danger: Do not plot!
 
 test_that("AllDescendantEdges() works", {
   pec5 <- UnrootTree(PectinateTree(5))
@@ -19,7 +19,7 @@ test_that("AllDescendantEdges() works", {
                DescendantEdges(edge = NULL, pec5$edge[, 1], pec5$edge[, 2]))
 })
 
-test_that('EdgeAncestry() works', {
+test_that("EdgeAncestry() works", {
   tree <- BalancedTree(10)
   edge <- tree$edge
   parent <- edge[, 1]
@@ -30,7 +30,7 @@ test_that('EdgeAncestry() works', {
   expect_equal(logical(18), EdgeAncestry(10, parent, child))
 })
 
-test_that('Root node can be found', {
+test_that("Root node can be found", {
   rooted <- BalancedTree(8)
   postorder <- Postorder(rooted)
   unrooted <- UnrootTree(rooted)
@@ -48,7 +48,7 @@ test_that('Root node can be found', {
   expect_warning(RootNode(matrix(1:4, 2)))
 })
 
-test_that('NodeOrder() works', {
+test_that("NodeOrder() works", {
   expect_equal(ignore_attr = TRUE, c(2L, rep(3L, 6)),
                as.integer(NodeOrder(BalancedTree(8), internalOnly = TRUE)))
   expect_equal(ignore_attr = TRUE, c(rep(1L, 8), 2L, rep(3L, 6)),
@@ -63,11 +63,11 @@ test_that('NodeOrder() works', {
   expect_equal(c(3, 2, 2), NDescendants(UnrootTree(PectinateTree(5))))
 })
 
-test_that('Rooting and partition counting', {
+test_that("Rooting and partition counting", {
   set.seed(0)
 
-  expect_false(TreeIsRooted(ape::read.tree(text='(a, b, c);')))
-  expect_true(TreeIsRooted(ape::read.tree(text='(a, (b, c));')))
+  expect_false(TreeIsRooted(ape::read.tree(text="(a, b, c);")))
+  expect_true(TreeIsRooted(ape::read.tree(text="(a, (b, c));")))
 
   tree8 <- RandomTree(8L, TRUE)
   expect_true(TreeIsRooted(tree8))
@@ -77,12 +77,12 @@ test_that('Rooting and partition counting', {
   expect_equal(5L, NPartitions(tree8))
   expect_equal(5L, NPartitions(UnrootTree(tree8)))
 
-  expect_equal(0L, NPartitions(ape::read.tree(text='(A, ((B, C)));')))
+  expect_equal(0L, NPartitions(ape::read.tree(text="(A, ((B, C)));")))
 
   expect_equal(c(5L, 5L), NPartitions(list(tree8, UnrootTree(tree8))))
   expect_equal(c(5L, 5L), NPartitions(c(8, 8)))
-  expect_equal(2L, NSplits('((a, b), (c, (d, e)));'))
-  expect_equal(0L, NSplits('a'))
+  expect_equal(2L, NSplits("((a, b), (c, (d, e)));"))
+  expect_equal(0L, NSplits("a"))
   expect_null(NSplits(NULL))
   expect_equal(0L, NSplits(letters[1:2]))
   expect_equal(3L, NSplits(letters[1:6]))
@@ -99,8 +99,8 @@ test_that("NTip() works", {
     expect_identical(NTip(list(tr)), n)
     expect_identical(rep(n, 2L), NTip(list(tr, tr)))
     expect_identical(rep(n, 3L),
-                     NTip(structure(list(tr, tr, pec), class = 'multiPhylo')))
-    expect_null(NTip(matrix('', n, 2)))
+                     NTip(structure(list(tr, tr, pec), class = "multiPhylo")))
+    expect_null(NTip(matrix("", n, 2)))
   }
   Test(1L)
   Test(8L)
@@ -125,8 +125,8 @@ test_that("MRCA() works", {
   expect_equal(9, MRCA(1, 11, allAnc))
 })
 
-test_that('Edge distances are calculated correctly', {
-  tree <- ape::read.tree(text = '(((a, b), (c, d)), (e, (f, (g, (h, i)))));')
+test_that("Edge distances are calculated correctly", {
+  tree <- ape::read.tree(text = "(((a, b), (c, d)), (e, (f, (g, (h, i)))));")
   ed <- EdgeDistances(tree)
 
   expect_equal(ed, t(ed)) # Symmetry
@@ -138,7 +138,7 @@ test_that('Edge distances are calculated correctly', {
   expect_equal(c(1, 2, 3, 3, 2, 3, 3, 1, 1, 0, 1, 1, 2, 2, 3, 3), ed[, 10])
   expect_equal(c(1, 0, 1, 1, 1, 2, 2, 1, 2, 2, 3, 3, 4, 4, 5, 5), ed[, 2])
 
-  tree <- ape::read.tree(text='(a, (b, (c, (d, (((e, f), g), (h, (i, j)))))));')
+  tree <- ape::read.tree(text="(a, (b, (c, (d, (((e, f), g), (h, (i, j)))))));")
   ed <- EdgeDistances(tree)
   expect_equal(ed, t(ed)) # Symmetry
   expect_equal(c(6, 6, 6, 5, 5, 4, 4, 3, 2, 1, 0, 1, 2, 3, 4, 4, 5, 5),
@@ -168,8 +168,8 @@ test_that("Node depths calculated correctly", {
   expect_equal(c(3,2,1,1,1,2,1,1,1,3,2,1,1,1,2,1,1,1),
                NodeDepth(tree, shortest = TRUE, includeTips = FALSE))
 
-  tree <- UnrootTree(RootTree(BalancedTree(20), 't10'))
-  #plot(tree); nodelabels(adj = 2, bg = 'yellow')
+  tree <- UnrootTree(RootTree(BalancedTree(20), "t10"))
+  #plot(tree); nodelabels(adj = 2, bg = "yellow")
   #nodelabels(NodeDepth(tree, F, FALSE))
   #nodelabels(NodeDepth(tree, T, FALSE))
   expect_equal(c(1,3,4,3,2,1,1,4,3,2,1,1,3,2,1,1,2,1),
@@ -193,7 +193,7 @@ test_that("Node depths calculated correctly", {
   expect_equal(1L, NodeDepth(StarTree(8), TRUE, FALSE))
 })
 
-test_that('SplitsInBinaryTree() works', {
+test_that("SplitsInBinaryTree() works", {
   expect_identical(5L, SplitsInBinaryTree(8))
   expect_identical(5L, SplitsInBinaryTree(as.phylo(0, 8)))
   expect_identical(rep(5L, 4), SplitsInBinaryTree(as.phylo(0:3, 8)))
